@@ -10,6 +10,7 @@
 # Copyright 2018 Maarten Fonville <mfonville@users.noreply.github.com>         #
 # Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2019 Nick Campbell <nicholas.j.campbell@gmail.com>                 #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -92,7 +93,9 @@ mediaTypeOrganizationInvitationPreview = "application/vnd.github.dazzler-preview
 mediaTypeTeamDiscussionsPreview = "application/vnd.github.echo-preview+json"
 
 # https://developer.github.com/changes/2018-03-16-protected-branches-required-approving-reviews/
-mediaTypeRequireMultipleApprovingReviews = "application/vnd.github.luke-cage-preview+json"
+mediaTypeRequireMultipleApprovingReviews = (
+    "application/vnd.github.luke-cage-preview+json"
+)
 
 # https://developer.github.com/changes/2018-05-24-user-migration-api/
 mediaTypeMigrationPreview = "application/vnd.github.wyandotte-preview+json"
@@ -108,3 +111,9 @@ vulnerabilityAlertsPreview = "application/vnd.github.dorian-preview+json"
 
 # https://developer.github.com/changes/2019-06-04-automated-security-fixes/
 automatedSecurityFixes = "application/vnd.github.london-preview+json"
+
+# https://developer.github.com/changes/2019-05-29-update-branch-api/
+updateBranchPreview = "application/vnd.github.lydian-preview+json"
+
+# https://developer.github.com/changes/2016-05-23-timeline-preview-api/
+issueTimelineEventsPreview = "application/vnd.github.mockingbird-preview"
