@@ -31,9 +31,9 @@
 ################################################################################
 
 from __future__ import absolute_import
-import github.GithubObject
 
 import github.GitAuthor
+import github.GithubObject
 import github.GitObject
 
 
@@ -105,12 +105,16 @@ class GitTag(github.GithubObject.CompletableGithubObject):
         if "message" in attributes:  # pragma no branch
             self._message = self._makeStringAttribute(attributes["message"])
         if "object" in attributes:  # pragma no branch
-            self._object = self._makeClassAttribute(github.GitObject.GitObject, attributes["object"])
+            self._object = self._makeClassAttribute(
+                github.GitObject.GitObject, attributes["object"]
+            )
         if "sha" in attributes:  # pragma no branch
             self._sha = self._makeStringAttribute(attributes["sha"])
         if "tag" in attributes:  # pragma no branch
             self._tag = self._makeStringAttribute(attributes["tag"])
         if "tagger" in attributes:  # pragma no branch
-            self._tagger = self._makeClassAttribute(github.GitAuthor.GitAuthor, attributes["tagger"])
+            self._tagger = self._makeClassAttribute(
+                github.GitAuthor.GitAuthor, attributes["tagger"]
+            )
         if "url" in attributes:  # pragma no branch
             self._url = self._makeStringAttribute(attributes["url"])
