@@ -31,6 +31,7 @@
 ################################################################################
 
 from __future__ import absolute_import
+
 import github.GithubObject
 
 
@@ -84,4 +85,6 @@ class HookDescription(github.GithubObject.NonCompletableGithubObject):
         if "schema" in attributes:  # pragma no branch
             self._schema = self._makeListOfListOfStringsAttribute(attributes["schema"])
         if "supported_events" in attributes:  # pragma no branch
-            self._supported_events = self._makeListOfStringsAttribute(attributes["supported_events"])
+            self._supported_events = self._makeListOfStringsAttribute(
+                attributes["supported_events"]
+            )
