@@ -24,6 +24,7 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 
 import github.GithubObject
 
@@ -112,13 +113,19 @@ class Invitation(github.GithubObject.CompletableGithubObject):
 
     def _useAttributes(self, attributes):
         if "repository" in attributes:  # pragma no branch
-            self._assignee = self._makeClassAttribute(github.Repository.Repository, attributes["repository"])
+            self._assignee = self._makeClassAttribute(
+                github.Repository.Repository, attributes["repository"]
+            )
         if "created_at" in attributes:  # pragma no branch
             self._closed_at = self._makeDatetimeAttribute(attributes["created_at"])
         if "invitee" in attributes:  # pragma no branch
-            self._invitee = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["invitee"])
+            self._invitee = self._makeClassAttribute(
+                github.NamedUser.NamedUser, attributes["invitee"]
+            )
         if "inviter" in attributes:  # pragma no branch
-            self._inviter = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["inviter"])
+            self._inviter = self._makeClassAttribute(
+                github.NamedUser.NamedUser, attributes["inviter"]
+            )
         if "id" in attributes:  # pragma no branch
             self._id = self._makeIntAttribute(attributes["id"])
 
