@@ -49,32 +49,35 @@
 ################################################################################
 
 from __future__ import absolute_import
-import datetime
 
+import datetime
 import pickle
 import time
-import requests
+
 import jwt
+import requests
+import six
 import urllib3
 
-from .Requester import Requester
-from . import AuthenticatedUser
-import github.NamedUser
 import github.Gist
-import github.PaginatedList
-from . import Repository
-from . import Installation
-import github.License
-import github.Topic
 import github.GithubObject
-from . import HookDescription
-from . import GitignoreTemplate
-from . import RateLimit
-from . import InstallationAuthorization
-from . import GithubException
+import github.License
+import github.NamedUser
+import github.PaginatedList
+import github.Topic
 
-from . import Consts
-import six
+from . import (
+    AuthenticatedUser,
+    Consts,
+    GithubException,
+    GitignoreTemplate,
+    HookDescription,
+    Installation,
+    InstallationAuthorization,
+    RateLimit,
+    Repository,
+)
+from .Requester import Requester
 
 DEFAULT_BASE_URL = "https://api.github.com"
 DEFAULT_STATUS_URL = "https://status.github.com"
@@ -90,7 +93,20 @@ class Github(object):
     This is the main class you instantiate to access the Github API v3. Optional parameters allow different authentication methods.
     """
 
-    def __init__(self, login_or_token=None, password=None, jwt=None, base_url=DEFAULT_BASE_URL, timeout=DEFAULT_TIMEOUT, client_id=None, client_secret=None, user_agent='PyGithub/Python', per_page=DEFAULT_PER_PAGE, api_preview=False, verify=True, retry=None):
+    def __init__(
+        self,
+        login_or_token=None,
+        password=None,
+        jwt=None,
+        base_url=DEFAULT_BASE_URL,
+        timeout=DEFAULT_TIMEOUT,
+        client_id=None,
+        client_secret=None,
+        user_agent="PyGithub/Python",
+        per_page=DEFAULT_PER_PAGE,
+        verify=True,
+        retry=None,
+    ):
         """
         :param login_or_token: string
         :param password: string
@@ -104,17 +120,40 @@ class Github(object):
         :param retry: int or urllib3.util.retry.Retry object
         """
 
-        assert login_or_token is None or isinstance(login_or_token, (str, six.text_type)), login_or_token
+        assert login_or_token is None or isinstance(
+            login_or_token, (str, six.text_type)
+        ), login_or_token
         assert password is None or isinstance(password, (str, six.text_type)), password
         assert jwt is None or isinstance(jwt, (str, six.text_type)), jwt
         assert isinstance(base_url, (str, six.text_type)), base_url
         assert isinstance(timeout, six.integer_types), timeout
-        assert client_id is None or isinstance(client_id, (str, six.text_type)), client_id
-        assert client_secret is None or isinstance(client_secret, (str, six.text_type)), client_secret
-        assert user_agent is None or isinstance(user_agent, (str, six.text_type)), user_agent
-        assert isinstance(api_preview, (bool))
-        assert retry is None or isinstance(retry, (int)) or isinstance(retry, (urllib3.util.Retry))
-        self.__requester = Requester(login_or_token, password, jwt, base_url, timeout, client_id, client_secret, user_agent, per_page, api_preview, verify, retry)
+        assert client_id is None or isinstance(
+            client_id, (str, six.text_type)
+        ), client_id
+        assert client_secret is None or isinstance(
+            client_secret, (str, six.text_type)
+        ), client_secret
+        assert user_agent is None or isinstance(
+            user_agent, (str, six.text_type)
+        ), user_agent
+        assert (
+            retry is None
+            or isinstance(retry, (int))
+            or isinstance(retry, (urllib3.util.Retry))
+        )
+        self.__requester = Requester(
+            login_or_token,
+            password,
+            jwt,
+            base_url,
+            timeout,
+            client_id,
+            client_secret,
+            user_agent,
+            per_page,
+            verify,
+            retry,
+        )
 
     def __get_FIX_REPO_GET_GIT_REF(self):
         """
@@ -125,7 +164,9 @@ class Github(object):
     def __set_FIX_REPO_GET_GIT_REF(self, value):
         self.__requester.FIX_REPO_GET_GIT_REF = value
 
-    FIX_REPO_GET_GIT_REF = property(__get_FIX_REPO_GET_GIT_REF, __set_FIX_REPO_GET_GIT_REF)
+    FIX_REPO_GET_GIT_REF = property(
+        __get_FIX_REPO_GET_GIT_REF, __set_FIX_REPO_GET_GIT_REF
+    )
 
     def __get_per_page(self):
         """
@@ -172,10 +213,7 @@ class Github(object):
         :calls: `GET /rate_limit <http://developer.github.com/v3/rate_limit>`_
         :rtype: :class:`github.RateLimit.RateLimit`
         """
-        headers, data = self.__requester.requestJsonAndCheck(
-            'GET',
-            '/rate_limit'
-        )
+        headers, data = self.__requester.requestJsonAndCheck("GET", "/rate_limit")
         return RateLimit.RateLimit(self.__requester, headers, data["resources"], True)
 
     @property
@@ -193,10 +231,7 @@ class Github(object):
         """
 
         assert isinstance(key, (str, six.text_type)), key
-        headers, data = self.__requester.requestJsonAndCheck(
-            "GET",
-            "/licenses/" + key
-        )
+        headers, data = self.__requester.requestJsonAndCheck("GET", "/licenses/" + key)
         return github.License.License(self.__requester, headers, data, completed=True)
 
     def get_licenses(self):
@@ -208,10 +243,7 @@ class Github(object):
         url_parameters = dict()
 
         return github.PaginatedList.PaginatedList(
-            github.License.License,
-            self.__requester,
-            "/licenses",
-            url_parameters
+            github.License.License, self.__requester, "/licenses", url_parameters
         )
 
     def get_user(self, login=github.GithubObject.NotSet):
@@ -220,15 +252,20 @@ class Github(object):
         :param login: string
         :rtype: :class:`github.NamedUser.NamedUser`
         """
-        assert login is github.GithubObject.NotSet or isinstance(login, (str, six.text_type)), login
+        assert login is github.GithubObject.NotSet or isinstance(
+            login, (str, six.text_type)
+        ), login
         if login is github.GithubObject.NotSet:
-            return AuthenticatedUser.AuthenticatedUser(self.__requester, {}, {"url": "/user"}, completed=False)
+            return AuthenticatedUser.AuthenticatedUser(
+                self.__requester, {}, {"url": "/user"}, completed=False
+            )
         else:
             headers, data = self.__requester.requestJsonAndCheck(
-                "GET",
-                "/users/" + login
+                "GET", "/users/" + login
+            )
+            return github.NamedUser.NamedUser(
+                self.__requester, headers, data, completed=True
             )
-            return github.NamedUser.NamedUser(self.__requester, headers, data, completed=True)
 
     def get_users(self, since=github.GithubObject.NotSet):
         """
@@ -236,15 +273,14 @@ class Github(object):
         :param since: integer
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
         """
-        assert since is github.GithubObject.NotSet or isinstance(since, six.integer_types), since
+        assert since is github.GithubObject.NotSet or isinstance(
+            since, six.integer_types
+        ), since
         url_parameters = dict()
         if since is not github.GithubObject.NotSet:
             url_parameters["since"] = since
         return github.PaginatedList.PaginatedList(
-            github.NamedUser.NamedUser,
-            self.__requester,
-            "/users",
-            url_parameters
+            github.NamedUser.NamedUser, self.__requester, "/users", url_parameters
         )
 
     def get_organization(self, login):
@@ -254,11 +290,10 @@ class Github(object):
         :rtype: :class:`github.Organization.Organization`
         """
         assert isinstance(login, (str, six.text_type)), login
-        headers, data = self.__requester.requestJsonAndCheck(
-            "GET",
-            "/orgs/" + login
+        headers, data = self.__requester.requestJsonAndCheck("GET", "/orgs/" + login)
+        return github.Organization.Organization(
+            self.__requester, headers, data, completed=True
         )
-        return github.Organization.Organization(self.__requester, headers, data, completed=True)
 
     def get_organizations(self, since=github.GithubObject.NotSet):
         """
@@ -266,7 +301,9 @@ class Github(object):
         :param since: integer
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Organization.Organization`
         """
-        assert since is github.GithubObject.NotSet or isinstance(since, six.integer_types), since
+        assert since is github.GithubObject.NotSet or isinstance(
+            since, six.integer_types
+        ), since
         url_parameters = dict()
         if since is not github.GithubObject.NotSet:
             url_parameters["since"] = since
@@ -274,7 +311,7 @@ class Github(object):
             github.Organization.Organization,
             self.__requester,
             "/organizations",
-            url_parameters
+            url_parameters,
         )
 
     def get_repo(self, full_name_or_id, lazy=False):
@@ -286,32 +323,37 @@ class Github(object):
         url_base = "/repositories/" if isinstance(full_name_or_id, int) else "/repos/"
         url = "%s%s" % (url_base, full_name_or_id)
         if lazy:
-            return Repository.Repository(self.__requester, {}, {"url": url}, completed=False)
+            return Repository.Repository(
+                self.__requester, {}, {"url": url}, completed=False
+            )
         headers, data = self.__requester.requestJsonAndCheck(
-            "GET",
-            "%s%s" % (url_base, full_name_or_id)
+            "GET", "%s%s" % (url_base, full_name_or_id)
         )
         return Repository.Repository(self.__requester, headers, data, completed=True)
 
-    def get_repos(self, since=github.GithubObject.NotSet, visibility=github.GithubObject.NotSet):
+    def get_repos(
+        self, since=github.GithubObject.NotSet, visibility=github.GithubObject.NotSet
+    ):
         """
         :calls: `GET /repositories <http://developer.github.com/v3/repos/#list-all-public-repositories>`_
         :param since: integer
         :param visibility: string ('all','public')
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Repository.Repository`
         """
-        assert since is github.GithubObject.NotSet or isinstance(since, six.integer_types), since
+        assert since is github.GithubObject.NotSet or isinstance(
+            since, six.integer_types
+        ), since
         url_parameters = dict()
         if since is not github.GithubObject.NotSet:
             url_parameters["since"] = since
         if visibility is not github.GithubObject.NotSet:
-            assert visibility in ('public', 'all'), visibility
+            assert visibility in ("public", "all"), visibility
             url_parameters["visibility"] = visibility
         return github.PaginatedList.PaginatedList(
             github.Repository.Repository,
             self.__requester,
             "/repositories",
-            url_parameters
+            url_parameters,
         )
 
     def get_project(self, id):
@@ -323,7 +365,7 @@ class Github(object):
         headers, data = self.__requester.requestJsonAndCheck(
             "GET",
             "/projects/%d" % (id),
-            headers={"Accept": Consts.mediaTypeProjectsPreview}
+            headers={"Accept": Consts.mediaTypeProjectsPreview},
         )
         return github.Project.Project(self.__requester, headers, data, completed=True)
 
@@ -334,10 +376,7 @@ class Github(object):
         :rtype: :class:`github.Gist.Gist`
         """
         assert isinstance(id, (str, six.text_type)), id
-        headers, data = self.__requester.requestJsonAndCheck(
-            "GET",
-            "/gists/" + id
-        )
+        headers, data = self.__requester.requestJsonAndCheck("GET", "/gists/" + id)
         return github.Gist.Gist(self.__requester, headers, data, completed=True)
 
     def get_gists(self, since=github.GithubObject.NotSet):
@@ -346,18 +385,23 @@ class Github(object):
         :param since: datetime.datetime format YYYY-MM-DDTHH:MM:SSZ
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Gist.Gist`
         """
-        assert since is github.GithubObject.NotSet or isinstance(since, datetime.datetime), since
+        assert since is github.GithubObject.NotSet or isinstance(
+            since, datetime.datetime
+        ), since
         url_parameters = dict()
         if since is not github.GithubObject.NotSet:
             url_parameters["since"] = since.strftime("%Y-%m-%dT%H:%M:%SZ")
         return github.PaginatedList.PaginatedList(
-            github.Gist.Gist,
-            self.__requester,
-            "/gists/public",
-            url_parameters
+            github.Gist.Gist, self.__requester, "/gists/public", url_parameters
         )
 
-    def search_repositories(self, query, sort=github.GithubObject.NotSet, order=github.GithubObject.NotSet, **qualifiers):
+    def search_repositories(
+        self,
+        query,
+        sort=github.GithubObject.NotSet,
+        order=github.GithubObject.NotSet,
+        **qualifiers
+    ):
         """
         :calls: `GET /search/repositories <http://developer.github.com/v3/search>`_
         :param query: string
@@ -368,11 +412,15 @@ class Github(object):
         """
         assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
-        if sort is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
-            assert sort in ('stars', 'forks', 'updated'), sort
+        if (
+            sort is not github.GithubObject.NotSet
+        ):  # pragma no branch (Should be covered)
+            assert sort in ("stars", "forks", "updated"), sort
             url_parameters["sort"] = sort
-        if order is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
-            assert order in ('asc', 'desc'), order
+        if (
+            order is not github.GithubObject.NotSet
+        ):  # pragma no branch (Should be covered)
+            assert order in ("asc", "desc"), order
             url_parameters["order"] = order
 
         query_chunks = []
@@ -382,17 +430,23 @@ class Github(object):
         for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
-        url_parameters["q"] = ' '.join(query_chunks)
+        url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
 
         return github.PaginatedList.PaginatedList(
             github.Repository.Repository,
             self.__requester,
             "/search/repositories",
-            url_parameters
+            url_parameters,
         )
 
-    def search_users(self, query, sort=github.GithubObject.NotSet, order=github.GithubObject.NotSet, **qualifiers):
+    def search_users(
+        self,
+        query,
+        sort=github.GithubObject.NotSet,
+        order=github.GithubObject.NotSet,
+        **qualifiers
+    ):
         """
         :calls: `GET /search/users <http://developer.github.com/v3/search>`_
         :param query: string
@@ -404,10 +458,10 @@ class Github(object):
         assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
         if sort is not github.GithubObject.NotSet:
-            assert sort in ('followers', 'repositories', 'joined'), sort
+            assert sort in ("followers", "repositories", "joined"), sort
             url_parameters["sort"] = sort
         if order is not github.GithubObject.NotSet:
-            assert order in ('asc', 'desc'), order
+            assert order in ("asc", "desc"), order
             url_parameters["order"] = order
 
         query_chunks = []
@@ -417,17 +471,23 @@ class Github(object):
         for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
-        url_parameters["q"] = ' '.join(query_chunks)
+        url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
 
         return github.PaginatedList.PaginatedList(
             github.NamedUser.NamedUser,
             self.__requester,
             "/search/users",
-            url_parameters
+            url_parameters,
         )
 
-    def search_issues(self, query, sort=github.GithubObject.NotSet, order=github.GithubObject.NotSet, **qualifiers):
+    def search_issues(
+        self,
+        query,
+        sort=github.GithubObject.NotSet,
+        order=github.GithubObject.NotSet,
+        **qualifiers
+    ):
         """
         :calls: `GET /search/issues <http://developer.github.com/v3/search>`_
         :param query: string
@@ -439,10 +499,10 @@ class Github(object):
         assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
         if sort is not github.GithubObject.NotSet:
-            assert sort in ('comments', 'created', 'updated'), sort
+            assert sort in ("comments", "created", "updated"), sort
             url_parameters["sort"] = sort
         if order is not github.GithubObject.NotSet:
-            assert order in ('asc', 'desc'), order
+            assert order in ("asc", "desc"), order
             url_parameters["order"] = order
 
         query_chunks = []
@@ -452,17 +512,21 @@ class Github(object):
         for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
-        url_parameters["q"] = ' '.join(query_chunks)
+        url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
 
         return github.PaginatedList.PaginatedList(
-            github.Issue.Issue,
-            self.__requester,
-            "/search/issues",
-            url_parameters
+            github.Issue.Issue, self.__requester, "/search/issues", url_parameters
         )
 
-    def search_code(self, query, sort=github.GithubObject.NotSet, order=github.GithubObject.NotSet, highlight=False, **qualifiers):
+    def search_code(
+        self,
+        query,
+        sort=github.GithubObject.NotSet,
+        order=github.GithubObject.NotSet,
+        highlight=False,
+        **qualifiers
+    ):
         """
         :calls: `GET /search/code <http://developer.github.com/v3/search>`_
         :param query: string
@@ -474,11 +538,15 @@ class Github(object):
         """
         assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
-        if sort is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
-            assert sort in ('indexed',), sort
+        if (
+            sort is not github.GithubObject.NotSet
+        ):  # pragma no branch (Should be covered)
+            assert sort in ("indexed",), sort
             url_parameters["sort"] = sort
-        if order is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
-            assert order in ('asc', 'desc'), order
+        if (
+            order is not github.GithubObject.NotSet
+        ):  # pragma no branch (Should be covered)
+            assert order in ("asc", "desc"), order
             url_parameters["order"] = order
 
         query_chunks = []
@@ -488,7 +556,7 @@ class Github(object):
         for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
-        url_parameters["q"] = ' '.join(query_chunks)
+        url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
 
         headers = {"Accept": Consts.highLightSearchPreview} if highlight else None
@@ -498,10 +566,16 @@ class Github(object):
             self.__requester,
             "/search/code",
             url_parameters,
-            headers=headers
+            headers=headers,
         )
 
-    def search_commits(self, query, sort=github.GithubObject.NotSet, order=github.GithubObject.NotSet, **qualifiers):
+    def search_commits(
+        self,
+        query,
+        sort=github.GithubObject.NotSet,
+        order=github.GithubObject.NotSet,
+        **qualifiers
+    ):
         """
         :calls: `GET /search/commits <http://developer.github.com/v3/search>`_
         :param query: string
@@ -512,11 +586,15 @@ class Github(object):
         """
         assert isinstance(query, (str, six.text_type)), query
         url_parameters = dict()
-        if sort is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
-            assert sort in ('author-date', 'committer-date'), sort
+        if (
+            sort is not github.GithubObject.NotSet
+        ):  # pragma no branch (Should be covered)
+            assert sort in ("author-date", "committer-date"), sort
             url_parameters["sort"] = sort
-        if order is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
-            assert order in ('asc', 'desc'), order
+        if (
+            order is not github.GithubObject.NotSet
+        ):  # pragma no branch (Should be covered)
+            assert order in ("asc", "desc"), order
             url_parameters["order"] = order
 
         query_chunks = []
@@ -526,7 +604,7 @@ class Github(object):
         for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
-        url_parameters["q"] = ' '.join(query_chunks)
+        url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
 
         return github.PaginatedList.PaginatedList(
@@ -534,9 +612,7 @@ class Github(object):
             self.__requester,
             "/search/commits",
             url_parameters,
-            headers={
-                "Accept": Consts.mediaTypeCommitSearchPreview
-            }
+            headers={"Accept": Consts.mediaTypeCommitSearchPreview},
         )
 
     def search_topics(self, query, **qualifiers):
@@ -556,7 +632,7 @@ class Github(object):
         for qualifier, value in qualifiers.items():
             query_chunks.append("%s:%s" % (qualifier, value))
 
-        url_parameters["q"] = ' '.join(query_chunks)
+        url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
 
         return github.PaginatedList.PaginatedList(
@@ -564,9 +640,7 @@ class Github(object):
             self.__requester,
             "/search/topics",
             url_parameters,
-            headers={
-                "Accept": Consts.mediaTypeTopicsPreview
-            }
+            headers={"Accept": Consts.mediaTypeTopicsPreview},
         )
 
     def render_markdown(self, text, context=github.GithubObject.NotSet):
@@ -577,17 +651,15 @@ class Github(object):
         :rtype: string
         """
         assert isinstance(text, (str, six.text_type)), text
-        assert context is github.GithubObject.NotSet or isinstance(context, github.Repository.Repository), context
-        post_parameters = {
-            "text": text
-        }
+        assert context is github.GithubObject.NotSet or isinstance(
+            context, github.Repository.Repository
+        ), context
+        post_parameters = {"text": text}
         if context is not github.GithubObject.NotSet:
             post_parameters["mode"] = "gfm"
             post_parameters["context"] = context._identity
         status, headers, data = self.__requester.requestJson(
-            "POST",
-            "/markdown",
-            input=post_parameters
+            "POST", "/markdown", input=post_parameters
         )
         return data
 
@@ -599,21 +671,24 @@ class Github(object):
         """
         assert isinstance(name, (str, six.text_type)), name
         headers, attributes = self.__requester.requestJsonAndCheck(
-            "GET",
-            "/hooks/" + name
+            "GET", "/hooks/" + name
+        )
+        return HookDescription.HookDescription(
+            self.__requester, headers, attributes, completed=True
         )
-        return HookDescription.HookDescription(self.__requester, headers, attributes, completed=True)
 
     def get_hooks(self):
         """
         :calls: `GET /hooks <http://developer.github.com/v3/repos/hooks/>`_
         :rtype: list of :class:`github.HookDescription.HookDescription`
         """
-        headers, data = self.__requester.requestJsonAndCheck(
-            "GET",
-            "/hooks"
-        )
-        return [HookDescription.HookDescription(self.__requester, headers, attributes, completed=True) for attributes in data]
+        headers, data = self.__requester.requestJsonAndCheck("GET", "/hooks")
+        return [
+            HookDescription.HookDescription(
+                self.__requester, headers, attributes, completed=True
+            )
+            for attributes in data
+        ]
 
     def get_gitignore_templates(self):
         """
@@ -621,8 +696,7 @@ class Github(object):
         :rtype: list of string
         """
         headers, data = self.__requester.requestJsonAndCheck(
-            "GET",
-            "/gitignore/templates"
+            "GET", "/gitignore/templates"
         )
         return data
 
@@ -633,20 +707,18 @@ class Github(object):
         """
         assert isinstance(name, (str, six.text_type)), name
         headers, attributes = self.__requester.requestJsonAndCheck(
-            "GET",
-            "/gitignore/templates/" + name
+            "GET", "/gitignore/templates/" + name
+        )
+        return GitignoreTemplate.GitignoreTemplate(
+            self.__requester, headers, attributes, completed=True
         )
-        return GitignoreTemplate.GitignoreTemplate(self.__requester, headers, attributes, completed=True)
 
     def get_emojis(self):
         """
         :calls: `GET /emojis <http://developer.github.com/v3/emojis/>`_
         :rtype: dictionary of type => url for emoji`
         """
-        headers, attributes = self.__requester.requestJsonAndCheck(
-            "GET",
-            "/emojis"
-        )
+        headers, attributes = self.__requester.requestJsonAndCheck("GET", "/emojis")
         return attributes
 
     def create_from_raw_data(self, klass, raw_data, headers={}):
@@ -688,7 +760,9 @@ class Github(object):
         :param id:
         :return:
         """
-        return Installation.Installation(self.__requester, headers={}, attributes={"id": id}, completed=True)
+        return Installation.Installation(
+            self.__requester, headers={}, attributes={"id": id}, completed=True
+        )
 
 
 class GithubIntegration(object):
@@ -716,19 +790,11 @@ class GithubIntegration(object):
         :return:
         """
         now = int(time.time())
-        payload = {
-            "iat": now,
-            "exp": now + expiration,
-            "iss": self.integration_id
-        }
-        encrypted = jwt.encode(
-            payload,
-            key=self.private_key,
-            algorithm="RS256"
-        )
+        payload = {"iat": now, "exp": now + expiration, "iss": self.integration_id}
+        encrypted = jwt.encode(payload, key=self.private_key, algorithm="RS256")
 
         if isinstance(encrypted, bytes):
-            encrypted = encrypted.decode('utf-8')
+            encrypted = encrypted.decode("utf-8")
 
         return encrypted
 
@@ -744,13 +810,15 @@ class GithubIntegration(object):
         if user_id:
             body = {"user_id": user_id}
         response = requests.post(
-            "{}/app/installations/{}/access_tokens".format(self.base_url, installation_id),
+            "{}/app/installations/{}/access_tokens".format(
+                self.base_url, installation_id
+            ),
             headers={
                 "Authorization": "Bearer {}".format(self.create_jwt()),
                 "Accept": Consts.mediaTypeIntegrationPreview,
-                "User-Agent": "PyGithub/Python"
+                "User-Agent": "PyGithub/Python",
             },
-            json=body
+            json=body,
         )
 
         if response.status_code == 201:
@@ -758,21 +826,18 @@ class GithubIntegration(object):
                 requester=None,  # not required, this is a NonCompletableGithubObject
                 headers={},  # not required, this is a NonCompletableGithubObject
                 attributes=response.json(),
-                completed=True
+                completed=True,
             )
         elif response.status_code == 403:
             raise GithubException.BadCredentialsException(
-                status=response.status_code,
-                data=response.text
+                status=response.status_code, data=response.text
             )
         elif response.status_code == 404:
             raise GithubException.UnknownObjectException(
-                status=response.status_code,
-                data=response.text
+                status=response.status_code, data=response.text
             )
         raise GithubException.GithubException(
-            status=response.status_code,
-            data=response.text
+            status=response.status_code, data=response.text
         )
 
     def get_installation(self, owner, repo):
@@ -790,7 +855,7 @@ class GithubIntegration(object):
 
         response = requests.get(
             "{}/repos/{}/{}/installation".format(self.base_url, owner, repo),
-            headers=headers
+            headers=headers,
         )
         response_dict = response.json()
         return Installation.Installation(None, headers, response_dict, True)
