@@ -38,19 +38,20 @@
 ################################################################################
 
 from __future__ import absolute_import
+
 import datetime
 
-import github.GithubObject
-import github.PaginatedList
+import six
 
+import github.Event
 import github.Gist
-import github.Repository
+import github.GithubObject
 import github.NamedUser
+import github.Organization
+import github.PaginatedList
 import github.Permissions
 import github.Plan
-import github.Organization
-import github.Event
-import six
+import github.Repository
 
 
 class NamedUser(github.GithubObject.CompletableGithubObject):
@@ -73,7 +74,11 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         return hash((self.id, self.login))
 
     def __eq__(self, other):
-        return isinstance(other, type(self)) and self.login == other.login and self.id == other.id
+        return (
+            isinstance(other, type(self))
+            and self.login == other.login
+            and self.id == other.id
+        )
 
     @property
     def avatar_url(self):
@@ -425,10 +430,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Event.Event`
         """
         return github.PaginatedList.PaginatedList(
-            github.Event.Event,
-            self._requester,
-            self.url + "/events",
-            None
+            github.Event.Event, self._requester, self.url + "/events", None
         )
 
     def get_followers(self):
@@ -437,10 +439,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
         """
         return github.PaginatedList.PaginatedList(
-            NamedUser,
-            self._requester,
-            self.url + "/followers",
-            None
+            NamedUser, self._requester, self.url + "/followers", None
         )
 
     def get_following(self):
@@ -449,10 +448,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
         """
         return github.PaginatedList.PaginatedList(
-            NamedUser,
-            self._requester,
-            self.url + "/following",
-            None
+            NamedUser, self._requester, self.url + "/following", None
         )
 
     def get_gists(self, since=github.GithubObject.NotSet):
@@ -461,15 +457,14 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :param since: datetime.datetime format YYYY-MM-DDTHH:MM:SSZ
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Gist.Gist`
         """
-        assert since is github.GithubObject.NotSet or isinstance(since, datetime.datetime), since
+        assert since is github.GithubObject.NotSet or isinstance(
+            since, datetime.datetime
+        ), since
         url_parameters = dict()
         if since is not github.GithubObject.NotSet:
             url_parameters["since"] = since.strftime("%Y-%m-%dT%H:%M:%SZ")
         return github.PaginatedList.PaginatedList(
-            github.Gist.Gist,
-            self._requester,
-            self.url + "/gists",
-            url_parameters
+            github.Gist.Gist, self._requester, self.url + "/gists", url_parameters
         )
 
     def get_keys(self):
@@ -478,10 +473,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.UserKey.UserKey`
         """
         return github.PaginatedList.PaginatedList(
-            github.UserKey.UserKey,
-            self._requester,
-            self.url + "/keys",
-            None
+            github.UserKey.UserKey, self._requester, self.url + "/keys", None
         )
 
     def get_orgs(self):
@@ -490,10 +482,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Organization.Organization`
         """
         return github.PaginatedList.PaginatedList(
-            github.Organization.Organization,
-            self._requester,
-            self.url + "/orgs",
-            None
+            github.Organization.Organization, self._requester, self.url + "/orgs", None
         )
 
     def get_public_events(self):
@@ -502,10 +491,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Event.Event`
         """
         return github.PaginatedList.PaginatedList(
-            github.Event.Event,
-            self._requester,
-            self.url + "/events/public",
-            None
+            github.Event.Event, self._requester, self.url + "/events/public", None
         )
 
     def get_public_received_events(self):
@@ -517,7 +503,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
             github.Event.Event,
             self._requester,
             self.url + "/received_events/public",
-            None
+            None,
         )
 
     def get_received_events(self):
@@ -526,10 +512,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Event.Event`
         """
         return github.PaginatedList.PaginatedList(
-            github.Event.Event,
-            self._requester,
-            self.url + "/received_events",
-            None
+            github.Event.Event, self._requester, self.url + "/received_events", None
         )
 
     def get_repo(self, name):
@@ -540,13 +523,18 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         """
         assert isinstance(name, (str, six.text_type)), name
         headers, data = self._requester.requestJsonAndCheck(
-            "GET",
-            "/repos/" + self.login + "/" + name
+            "GET", "/repos/" + self.login + "/" + name
+        )
+        return github.Repository.Repository(
+            self._requester, headers, data, completed=True
         )
-        return github.Repository.Repository(self._requester, headers, data, completed=True)
 
-    def get_repos(self, type=github.GithubObject.NotSet, sort=github.GithubObject.NotSet,
-                  direction=github.GithubObject.NotSet):
+    def get_repos(
+        self,
+        type=github.GithubObject.NotSet,
+        sort=github.GithubObject.NotSet,
+        direction=github.GithubObject.NotSet,
+    ):
         """
         :calls: `GET /users/:user/repos <http://developer.github.com/v3/repos>`_
         :param type: string
@@ -554,9 +542,15 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :param direction: string
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Repository.Repository`
         """
-        assert type is github.GithubObject.NotSet or isinstance(type, (str, six.text_type)), type
-        assert sort is github.GithubObject.NotSet or isinstance(sort, (str, six.text_type)), sort
-        assert direction is github.GithubObject.NotSet or isinstance(direction, (str, six.text_type)), direction
+        assert type is github.GithubObject.NotSet or isinstance(
+            type, (str, six.text_type)
+        ), type
+        assert sort is github.GithubObject.NotSet or isinstance(
+            sort, (str, six.text_type)
+        ), sort
+        assert direction is github.GithubObject.NotSet or isinstance(
+            direction, (str, six.text_type)
+        ), direction
         url_parameters = dict()
         if type is not github.GithubObject.NotSet:
             url_parameters["type"] = type
@@ -568,7 +562,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
             github.Repository.Repository,
             self._requester,
             self.url + "/repos",
-            url_parameters
+            url_parameters,
         )
 
     def get_starred(self):
@@ -577,10 +571,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Repository.Repository`
         """
         return github.PaginatedList.PaginatedList(
-            github.Repository.Repository,
-            self._requester,
-            self.url + "/starred",
-            None
+            github.Repository.Repository, self._requester, self.url + "/starred", None
         )
 
     def get_subscriptions(self):
@@ -592,7 +583,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
             github.Repository.Repository,
             self._requester,
             self.url + "/subscriptions",
-            None
+            None,
         )
 
     def get_watched(self):
@@ -601,10 +592,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Repository.Repository`
         """
         return github.PaginatedList.PaginatedList(
-            github.Repository.Repository,
-            self._requester,
-            self.url + "/watched",
-            None
+            github.Repository.Repository, self._requester, self.url + "/watched", None
         )
 
     def has_in_following(self, following):
@@ -615,8 +603,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         """
         assert isinstance(following, github.NamedUser.NamedUser), following
         status, headers, data = self._requester.requestJson(
-            "GET",
-            self.url + "/following/" + following._identity
+            "GET", self.url + "/following/" + following._identity
         )
         return status == 204
 
@@ -630,14 +617,17 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         :param org: string or :class:`github.Organization.Organization`
         :rtype: :class:`github.Membership.Membership`
         """
-        assert isinstance(org, (str, six.text_type)) or isinstance(org, github.Organization.Organization), org
+        assert isinstance(org, (str, six.text_type)) or isinstance(
+            org, github.Organization.Organization
+        ), org
         if isinstance(org, github.Organization.Organization):
             org = org.login
         headers, data = self._requester.requestJsonAndCheck(
-            "GET",
-            "/orgs/" + org + "/memberships/" + self.login
+            "GET", "/orgs/" + org + "/memberships/" + self.login
+        )
+        return github.Membership.Membership(
+            self._requester, headers, data, completed=True
         )
-        return github.Membership.Membership(self._requester, headers, data, completed=True)
 
     def _initAttributes(self):
         self._avatar_url = github.GithubObject.NotSet
@@ -725,9 +715,13 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         if "id" in attributes:  # pragma no branch
             self._id = self._makeIntAttribute(attributes["id"])
         if "invitation_teams_url" in attributes:  # pragma no branch
-            self._invitation_teams_url = self._makeStringAttribute(attributes["invitation_teams_url"])
+            self._invitation_teams_url = self._makeStringAttribute(
+                attributes["invitation_teams_url"]
+            )
         if "inviter" in attributes:  # pragma no branch
-            self._inviter = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["inviter"])
+            self._inviter = self._makeClassAttribute(
+                github.NamedUser.NamedUser, attributes["inviter"]
+            )
         if "location" in attributes:  # pragma no branch
             self._location = self._makeStringAttribute(attributes["location"])
         if "login" in attributes:  # pragma no branch
@@ -737,11 +731,17 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         if "node_id" in attributes:  # pragma no branch
             self._node_id = self._makeStringAttribute(attributes["node_id"])
         if "organizations_url" in attributes:  # pragma no branch
-            self._organizations_url = self._makeStringAttribute(attributes["organizations_url"])
+            self._organizations_url = self._makeStringAttribute(
+                attributes["organizations_url"]
+            )
         if "owned_private_repos" in attributes:  # pragma no branch
-            self._owned_private_repos = self._makeIntAttribute(attributes["owned_private_repos"])
+            self._owned_private_repos = self._makeIntAttribute(
+                attributes["owned_private_repos"]
+            )
         if "permissions" in attributes:  # pragma no branch
-            self._permissions = self._makeClassAttribute(github.Permissions.Permissions, attributes["permissions"])
+            self._permissions = self._makeClassAttribute(
+                github.Permissions.Permissions, attributes["permissions"]
+            )
         if "plan" in attributes:  # pragma no branch
             self._plan = self._makeClassAttribute(github.Plan.Plan, attributes["plan"])
         if "private_gists" in attributes:  # pragma no branch
@@ -751,7 +751,9 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         if "public_repos" in attributes:  # pragma no branch
             self._public_repos = self._makeIntAttribute(attributes["public_repos"])
         if "received_events_url" in attributes:  # pragma no branch
-            self._received_events_url = self._makeStringAttribute(attributes["received_events_url"])
+            self._received_events_url = self._makeStringAttribute(
+                attributes["received_events_url"]
+            )
         if "repos_url" in attributes:  # pragma no branch
             self._repos_url = self._makeStringAttribute(attributes["repos_url"])
         if "role" in attributes:  # pragma no branch
@@ -761,13 +763,17 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         if "starred_url" in attributes:  # pragma no branch
             self._starred_url = self._makeStringAttribute(attributes["starred_url"])
         if "subscriptions_url" in attributes:  # pragma no branch
-            self._subscriptions_url = self._makeStringAttribute(attributes["subscriptions_url"])
+            self._subscriptions_url = self._makeStringAttribute(
+                attributes["subscriptions_url"]
+            )
         if "suspended_at" in attributes:  # pragma no branch
             self._suspended_at = self._makeDatetimeAttribute(attributes["suspended_at"])
         if "team_count" in attributes:
             self._team_count = self._makeIntAttribute(attributes["team_count"])
         if "total_private_repos" in attributes:  # pragma no branch
-            self._total_private_repos = self._makeIntAttribute(attributes["total_private_repos"])
+            self._total_private_repos = self._makeIntAttribute(
+                attributes["total_private_repos"]
+            )
         if "type" in attributes:  # pragma no branch
             self._type = self._makeStringAttribute(attributes["type"])
         if "updated_at" in attributes:  # pragma no branch
