@@ -29,11 +29,11 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import absolute_import
 
 import github.GithubObject
-
-import github.Repository
 import github.NotificationSubject
+import github.Repository
 
 
 class Notification(github.GithubObject.CompletableGithubObject):
@@ -120,23 +120,16 @@ class Notification(github.GithubObject.CompletableGithubObject):
         """
         :calls: `PATCH /notifications/threads/:id <https://developer.github.com/v3/activity/notifications/>`_
         """
-        headers, data = self._requester.requestJsonAndCheck(
-            "PATCH",
-            self.url,
-        )
+        headers, data = self._requester.requestJsonAndCheck("PATCH", self.url,)
 
     def get_pull_request(self):
-        headers, data = self._requester.requestJsonAndCheck(
-            "GET",
-            self.subject.url
+        headers, data = self._requester.requestJsonAndCheck("GET", self.subject.url)
+        return github.PullRequest.PullRequest(
+            self._requester, headers, data, completed=True
         )
-        return github.PullRequest.PullRequest(self._requester, headers, data, completed=True)
 
     def get_issue(self):
-        headers, data = self._requester.requestJsonAndCheck(
-            "GET",
-            self.subject.url
-        )
+        headers, data = self._requester.requestJsonAndCheck("GET", self.subject.url)
         return github.Issue.Issue(self._requester, headers, data, completed=True)
 
     def _initAttributes(self):
@@ -155,13 +148,19 @@ class Notification(github.GithubObject.CompletableGithubObject):
         if "last_read_at" in attributes:  # pragma no branch
             self._last_read_at = self._makeDatetimeAttribute(attributes["last_read_at"])
         if "repository" in attributes:  # pragma no branch
-            self._repository = self._makeClassAttribute(github.Repository.Repository, attributes["repository"])
+            self._repository = self._makeClassAttribute(
+                github.Repository.Repository, attributes["repository"]
+            )
         if "subject" in attributes:  # pragma no branch
-            self._subject = self._makeClassAttribute(github.NotificationSubject.NotificationSubject, attributes["subject"])
+            self._subject = self._makeClassAttribute(
+                github.NotificationSubject.NotificationSubject, attributes["subject"]
+            )
         if "reason" in attributes:  # pragma no branch
             self._reason = self._makeStringAttribute(attributes["reason"])
         if "subscription_url" in attributes:  # pragma no branch
-            self._subscription_url = self._makeStringAttribute(attributes["subscription_url"])
+            self._subscription_url = self._makeStringAttribute(
+                attributes["subscription_url"]
+            )
         if "unread" in attributes:  # pragma no branch
             self._unread = self._makeBoolAttribute(attributes["unread"])
         if "updated_at" in attributes:  # pragma no branch
