@@ -35,11 +35,13 @@
 ################################################################################
 
 from __future__ import absolute_import
+
+import six
+
 import github.GithubObject
 import github.NamedUser
 
 from . import Consts
-import six
 
 
 class PullRequestComment(github.GithubObject.CompletableGithubObject):
@@ -175,10 +177,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :calls: `DELETE /repos/:owner/:repo/pulls/comments/:number <http://developer.github.com/v3/pulls/comments>`_
         :rtype: None
         """
-        headers, data = self._requester.requestJsonAndCheck(
-            "DELETE",
-            self.url
-        )
+        headers, data = self._requester.requestJsonAndCheck("DELETE", self.url)
 
     def edit(self, body):
         """
@@ -191,9 +190,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
             "body": body,
         }
         headers, data = self._requester.requestJsonAndCheck(
-            "PATCH",
-            self.url,
-            input=post_parameters
+            "PATCH", self.url, input=post_parameters
         )
         self._useAttributes(data)
 
@@ -208,7 +205,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
             self._requester,
             self.url + "/reactions",
             None,
-            headers={'Accept': Consts.mediaTypeReactionsPreview}
+            headers={"Accept": Consts.mediaTypeReactionsPreview},
         )
 
     def create_reaction(self, reaction_type):
@@ -218,9 +215,17 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         :param reaction_type: string
         :rtype: :class:`github.Reaction.Reaction`
         """
-        assert isinstance(reaction_type, (str, six.text_type)), "reaction type should be a string"
-        assert reaction_type in ["+1", "-1", "laugh", "confused", "heart", "hooray"], \
-            "Invalid reaction type (https://developer.github.com/v3/reactions/#reaction-types)"
+        assert isinstance(
+            reaction_type, (str, six.text_type)
+        ), "reaction type should be a string"
+        assert reaction_type in [
+            "+1",
+            "-1",
+            "laugh",
+            "confused",
+            "heart",
+            "hooray",
+        ], "Invalid reaction type (https://developer.github.com/v3/reactions/#reaction-types)"
 
         post_parameters = {
             "content": reaction_type,
@@ -229,7 +234,7 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
             "POST",
             self.url + "/reactions",
             input=post_parameters,
-            headers={'Accept': Consts.mediaTypeReactionsPreview}
+            headers={"Accept": Consts.mediaTypeReactionsPreview},
         )
         return github.Reaction.Reaction(self._requester, headers, data, completed=True)
 
@@ -264,15 +269,21 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         if "in_reply_to_id" in attributes:  # pragma no branch
             self._in_reply_to_id = self._makeIntAttribute(attributes["in_reply_to_id"])
         if "original_commit_id" in attributes:  # pragma no branch
-            self._original_commit_id = self._makeStringAttribute(attributes["original_commit_id"])
+            self._original_commit_id = self._makeStringAttribute(
+                attributes["original_commit_id"]
+            )
         if "original_position" in attributes:  # pragma no branch
-            self._original_position = self._makeIntAttribute(attributes["original_position"])
+            self._original_position = self._makeIntAttribute(
+                attributes["original_position"]
+            )
         if "path" in attributes:  # pragma no branch
             self._path = self._makeStringAttribute(attributes["path"])
         if "position" in attributes:  # pragma no branch
             self._position = self._makeIntAttribute(attributes["position"])
         if "pull_request_url" in attributes:  # pragma no branch
-            self._pull_request_url = self._makeStringAttribute(attributes["pull_request_url"])
+            self._pull_request_url = self._makeStringAttribute(
+                attributes["pull_request_url"]
+            )
         if "updated_at" in attributes:  # pragma no branch
             self._updated_at = self._makeDatetimeAttribute(attributes["updated_at"])
         if "url" in attributes:  # pragma no branch
@@ -280,4 +291,6 @@ class PullRequestComment(github.GithubObject.CompletableGithubObject):
         if "html_url" in attributes:  # pragma no branch
             self._html_url = self._makeStringAttribute(attributes["html_url"])
         if "user" in attributes:  # pragma no branch
-            self._user = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["user"])
+            self._user = self._makeClassAttribute(
+                github.NamedUser.NamedUser, attributes["user"]
+            )
