@@ -31,10 +31,10 @@
 ################################################################################
 
 from __future__ import absolute_import
-import github.GithubObject
 
-import github.Repository
+import github.GithubObject
 import github.NamedUser
+import github.Repository
 
 
 class PullRequestPart(github.GithubObject.NonCompletableGithubObject):
@@ -93,8 +93,12 @@ class PullRequestPart(github.GithubObject.NonCompletableGithubObject):
         if "ref" in attributes:  # pragma no branch
             self._ref = self._makeStringAttribute(attributes["ref"])
         if "repo" in attributes:  # pragma no branch
-            self._repo = self._makeClassAttribute(github.Repository.Repository, attributes["repo"])
+            self._repo = self._makeClassAttribute(
+                github.Repository.Repository, attributes["repo"]
+            )
         if "sha" in attributes:  # pragma no branch
             self._sha = self._makeStringAttribute(attributes["sha"])
         if "user" in attributes:  # pragma no branch
-            self._user = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["user"])
+            self._user = self._makeClassAttribute(
+                github.NamedUser.NamedUser, attributes["user"]
+            )
