@@ -23,7 +23,9 @@
 ################################################################################
 
 from __future__ import absolute_import
+
 import github.GithubObject
+from github import Consts
 
 
 class SourceImport(github.GithubObject.CompletableGithubObject):
@@ -32,12 +34,14 @@ class SourceImport(github.GithubObject.CompletableGithubObject):
     """
 
     def __repr__(self):
-        return self.get__repr__({
-            "vcs_url": self._vcs_url.value,
-            "repository_url": self._repository_url.value,
-            "status": self._status.value,
-            "url": self._url.value
-        })
+        return self.get__repr__(
+            {
+                "vcs_url": self._vcs_url.value,
+                "repository_url": self._repository_url.value,
+                "status": self._status.value,
+                "url": self._url.value,
+            }
+        )
 
     @property
     def authors_count(self):
@@ -143,6 +147,10 @@ class SourceImport(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._vcs_url)
         return self._vcs_url.value
 
+    def update(self):
+        import_header = {"Accept": Consts.mediaTypeImportPreview}
+        return super(SourceImport, self).update(additional_headers=import_header)
+
     def _initAttributes(self):
         self._authors_count = github.GithubObject.NotSet
         self._authors_url = github.GithubObject.NotSet
@@ -164,15 +172,23 @@ class SourceImport(github.GithubObject.CompletableGithubObject):
         if "authors_url" in attributes:  # pragma no branch
             self._authors_url = self._makeStringAttribute(attributes["authors_url"])
         if "has_large_files" in attributes:  # pragma no branch
-            self._has_large_files = self._makeBoolAttribute(attributes["has_large_files"])
+            self._has_large_files = self._makeBoolAttribute(
+                attributes["has_large_files"]
+            )
         if "html_url" in attributes:  # pragma no branch
             self._html_url = self._makeStringAttribute(attributes["html_url"])
         if "large_files_count" in attributes:  # pragma no branch
-            self._large_files_count = self._makeIntAttribute(attributes["large_files_count"])
+            self._large_files_count = self._makeIntAttribute(
+                attributes["large_files_count"]
+            )
         if "large_files_size" in attributes:  # pragma no branch
-            self._large_files_size = self._makeIntAttribute(attributes["large_files_size"])
+            self._large_files_size = self._makeIntAttribute(
+                attributes["large_files_size"]
+            )
         if "repository_url" in attributes:  # pragma no branch
-            self._repository_url = self._makeStringAttribute(attributes["repository_url"])
+            self._repository_url = self._makeStringAttribute(
+                attributes["repository_url"]
+            )
         if "status" in attributes:  # pragma no branch
             self._status = self._makeStringAttribute(attributes["status"])
         if "status_text" in attributes:  # pragma no branch
