@@ -27,6 +27,7 @@
 ################################################################################
 
 from __future__ import absolute_import
+
 import github
 
 
@@ -58,7 +59,9 @@ class Stargazer(github.GithubObject.NonCompletableGithubObject):
         self._url = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
-        if 'starred_at' in attributes:
-            self._starred_at = self._makeDatetimeAttribute(attributes['starred_at'])
-        if 'user' in attributes:
-            self._user = self._makeClassAttribute(github.NamedUser.NamedUser, attributes['user'])
+        if "starred_at" in attributes:
+            self._starred_at = self._makeDatetimeAttribute(attributes["starred_at"])
+        if "user" in attributes:
+            self._user = self._makeClassAttribute(
+                github.NamedUser.NamedUser, attributes["user"]
+            )
